#include "LRSplitterFilter.h"

CLRSplitterFilter::CLRSplitterFilter(void)
{
	reset();
}

CLRSplitterFilter::~CLRSplitterFilter(void)
{
}

void CLRSplitterFilter::reset()
{
	biQuadLP.flushDelays();
	biQuadHP.flushDelays();
}

void CLRSplitterFilter::update()
{
	float theta_c = 2.0*pi*fc/sampleRate;

	float omega_c = pi*fc;

	float k = omega_c/tan(theta_c);
	float k_squared = k*k;

	float omega_c_squared = omega_c*omega_c;

	float fDenominator = k_squared + omega_c_squared + 2.0*k*omega_c;
	
	float fb1_Num = -2.0*k_squared + 2.0*omega_c_squared;
	float fb2_Num = -2.0*k*omega_c + k_squared + omega_c_squared;

	// --- low
	biQuadLP.m_f_a0 = omega_c_squared/fDenominator;
	biQuadLP.m_f_a1 = 2.0*omega_c_squared/fDenominator;
	biQuadLP.m_f_a2 = biQuadLP.m_f_a0;
	biQuadLP.m_f_b1 = fb1_Num/fDenominator;  // NOT keeping b's positive to match DSP Filters book by Jayant and Brent
	biQuadLP.m_f_b2 = fb2_Num/fDenominator;

	// --- high
	biQuadHP.m_f_a0 = k_squared/fDenominator;
	biQuadHP.m_f_a1 = -2.0*k_squared/fDenominator;
	biQuadHP.m_f_a2 = biQuadHP.m_f_a0;
	biQuadHP.m_f_b1 = fb1_Num/fDenominator;  // NOT keeping b's positive to match DSP Filters book by Jayant and Brent
	biQuadHP.m_f_b2 = fb2_Num/fDenominator;

}
void CLRSplitterFilter::doSplitFilter(float input, float& lowOuput, float& highOuput)
{
	// --- split
	lowOuput = biQuadLP.doBiQuad(input);

	// --- invert either ONE of them
	highOuput = -1.0*biQuadHP.doBiQuad(input);

}
